package vfl;
import JSci.maths.ExtraMath;
import java.awt.*;
import java.util.*;
import java.awt.geom.*;


public class TotalPressure implements SeaObject {
	private double ox;
	private int cx;
	private int sy;
	private double xfactor;
	private int yend;
	
	private double wd;
	private double gravity;
	private double amp;
	private double k;
	private double height;
	private double w;
	private double time;
	private double[] pressure;
	
	public TotalPressure (double cx, double wd,double gravity, double amp, double k,
	                     double height, double omega, double time,
	                     double xfactor, double yfactor, double xstart, double ystart ) {
	                     	
		this.cx = (int) ((cx-xstart) * xfactor);
		this.ox = cx;
		this.wd = wd;
		this.gravity = gravity;
		this.amp = amp;
        this.k = k;
        this.w = omega;
        this.height = height;
        this.time = time;
        this.xfactor = xfactor;
        
        this.sy = (int)((-ystart-0) *yfactor);   
        this.yend = (int)((height+0)*yfactor);
        this.pressure = new double[yend+1];
        
        double ry = 0;
        double rr = height / (double)yend;
        for (int y = 0; y<= yend; y++){ 
           pressure[y] = xfactor* ( (wd * gravity*amp * ExtraMath.cosh (k * (-ry+height)) * 
                         Math.cos ((k*ox) - (w*time)) / ExtraMath.cosh (k*height)) - (wd*gravity*- ry)); 
    
           ry+=rr;
        }	
        	
        
	
	}
	                     
	
    public void move(double t) {
        this.time = this.time + t;
     	double ry = 0;
        double rr = height / (double)yend;
        for (int y = 0; y<= yend; y++){ 
           pressure[y] = xfactor* ( (wd * gravity*amp * ExtraMath.cosh (k * (-ry+height)) * 
                         Math.cos ((k*ox) - (w*time)) / ExtraMath.cosh (k*height)) - (wd*gravity* -ry)); 
           ry+=rr;
        }	
    }
    
    
    public void moveTo(double t) {
    	this.time = t;
     	double ry = 0;
        double rr = height / (double)yend;
        for (int y = 0; y<= yend; y++){ 
           pressure[y] = xfactor* ( (wd * gravity*amp * ExtraMath.cosh (k * (-ry+height)) * 
                         Math.cos ((k*ox) - (w*time)) / ExtraMath.cosh (k*height)) - (wd*gravity*- ry)); 
           ry+=rr;
        }
	}
    public void paint(Graphics g) {
    	
    	GeneralPath gp = new GeneralPath();
        gp.moveTo((float)pressure[0]+cx, (float)(sy));
        Graphics2D g2 = (Graphics2D)g;
        g2.setColor(Color.orange);
        
        for (int i = 1; i <= yend; i++) {
            gp.lineTo((float)pressure[i]+cx,(float)i+sy);
            
            //g.fillOval((int)Math.round(pressure[i]+cx),(int)i+sy,1,1);	
        	//g.fillOval(i+cx,(int)i+sy,1,1);	

        }
        g2.draw(gp);
    	
    	
   }

	
}

